# Robot Framework Find Unused

Find unused parts of your Robot Framework project.

[Robocop](https://github.com/MarketSquare/robotframework-robocop) is great at finding unused parts
in a single file. Find unused finds unused parts across all your project files.

Allows you to find unused:

- Keywords
- Keyword arguments
- Keyword return statements
- Global variables

## Installation

Install with pip

```shell
pip install robotframework-find-unused
```

## How to use

- CLI
- API

## [Important remarks]

## Contributing

## Testing
